@@ -17,7 +17,7 @@ def update_ddns_server(updater_urls="/etc/external_ip_updater/urls.yaml", update
         if external_ip == None:
             log.warn("Unable to determine external IP.  This may be temporary or not.  Verify this warning doesn't persist.")
             return
-        log.debug("External IP address {}".format(str(external_ip)))            
+        log.debug("External IP address {}".format(str(external_ip)))        
         ddns_urls = read_yaml_update_urls(updater_urls)
         for domain, update_url in ddns_urls.items():
             log.debug("For domain: {}, the update url is: {}".format(domain,update_url))
@@ -67,8 +67,12 @@ def get_yaml_setting(setting="urls"):
     f = open(yaml_file)
     url_updater_hash = yaml.load(f)
     log.debug("yaml hash: {}".format(url_updater_hash))
-    return url_updater_hash[setting]
-
+    try:
+        return url_updater_hash[setting]
+    except KeyError as ke:
+        log.warn("key: {} not in file: {}".format(setting, yaml_file))
+        return False
+    
 def ip_addy_changed(external_ip, prev_ext_ip):
     if prev_ext_ip == None:
         return True
@@ -108,6 +112,16 @@ def get_ip():
     output = "{}".format(check_output(cmd, shell=True).strip().decode("utf-8", "ignore"))
     return output
 
+##########################################
+# Settings
+#--------------
+ip_cache_file = '/tmp/.current_external_ip'
+yaml_file = '/etc/external_ip_updater/urls.yaml'
+periodic_force_update_timer = time.time()
+periodic_force_update_period_seconds = get_periodic_force_update_period()
+log_file = get_yaml_setting(setting="logfile")
+log_file = log_file if log_file else 'external_ip.logger'
+    
 #################################
 # TESTS
 
@@ -132,17 +146,14 @@ def test_yaml():
 def test_get_webpage():
     html = get_simple_webpage('http://www.ip-secrets.com/')
 
+def test_logfile_setting():
+    print("log file: {}".format(log_file))
+
 if __name__ == '__main__':
     log.basicConfig(level=log.DEBUG)
     # set_trace()
-    test_update_ip()
+    # test_update_ip()
     # test_get_update_period()
     # test_get_ip()
-
-##########################################
-# Settings
-#--------------
-ip_cache_file = '/tmp/.current_external_ip'
-yaml_file = '/etc/external_ip_updater/urls.yaml'
-periodic_force_update_timer = time.time()
-periodic_force_update_period_seconds = get_periodic_force_update_period()
+    test_logfile_setting()
+    
